@@ -18,7 +18,11 @@ from climetlab.decorators import locked
 LOG = logging.getLogger(__name__)
 
 
-class Reader(Base, os.PathLike):
+class ReaderMeta(type(Base), type(os.PathLike)):
+    pass
+
+
+class Reader(Base, os.PathLike, metaclass=ReaderMeta):
 
     appendable = False  # Set to True if the data can be appened to and existing file
     binary = True
@@ -88,13 +92,17 @@ _READERS = {}
 def _readers():
     if not _READERS:
         here = os.path.dirname(__file__)
-        for path in os.listdir(here):
+        for path in sorted(os.listdir(here)):
             if path.endswith(".py") and path[0] not in ("_", "."):
                 name, _ = os.path.splitext(path)
                 try:
                     module = import_module(f".{name}", package=__name__)
                     if hasattr(module, "reader"):
                         _READERS[name] = module.reader
+                        if hasattr(module, "aliases"):
+                            for a in module.aliases:
+                                assert a not in _READERS
+                                _READERS[a] = module.reader
                 except Exception:
                     LOG.exception("Error loading reader %s", name)
     return _READERS
@@ -104,6 +112,18 @@ def reader(source, path):
 
     assert isinstance(path, str), source
 
+    if hasattr(source, "reader"):
+        reader = source.reader
+        LOG.debug("Looking for a reader for %s (%s)", path, reader)
+        if callable(reader):
+            return reader(source, path)
+        if isinstance(reader, str):
+            return _readers()[reader.replace("-", "_")](source, path, None, False)
+
+        raise TypeError(
+            "Provided reader must be a callable or a string, not %s" % type(reader)
+        )
+
     if os.path.isdir(path):
         from .directory import DirectoryReader
 
