@@ -187,11 +187,21 @@ class CSVReader(Reader):
             **options,
         )
 
-    def plot_map(self, driver):
-        get_wrapper(self.to_pandas()).plot_map(driver)
+    def plot_graph(self, backend):
+        get_wrapper(self.to_pandas()).plot_graph(backend)
+
+    def plot_map(self, backend):
+        get_wrapper(self.to_pandas()).plot_map(backend)
+
+    def to_metview(self):
+        from climetlab.metview import mv_read_table
+
+        assert self.compression is None
+        # TODO: use dialect
+        return mv_read_table(table_filename=self.path)
 
 
-def reader(source, path, magic, deeper_check):
+def reader(source, path, magic, deeper_check, fwf=False):
     kind, compression = mimetypes.guess_type(path)
 
     if kind == "text/csv":
