@@ -18,6 +18,7 @@ import xarray as xr
 
 from climetlab.core import Base
 from climetlab.utils.bbox import BoundingBox
+from climetlab.utils.dates import to_datetime
 
 from . import Reader
 
@@ -140,7 +141,7 @@ class DataSet:
 
 
 class NetCDFField(Base):
-    def __init__(self, path, ds, variable, slices):
+    def __init__(self, path, ds, variable, slices, non_dim_coords):
 
         data_array = ds[variable]
 
@@ -149,6 +150,7 @@ class NetCDFField(Base):
         self.path = path
         self.variable = variable
         self.slices = slices
+        self.non_dim_coords = non_dim_coords
 
         self.name = self.variable
 
@@ -158,7 +160,9 @@ class NetCDFField(Base):
             getattr(data_array, "standard_name", self.variable),
         )
 
-        self.time = None
+        self.time = non_dim_coords.get("valid_time", non_dim_coords.get("time"))
+
+        # print('====', non_dim_coords)
 
         for s in self.slices:
 
@@ -168,15 +172,15 @@ class NetCDFField(Base):
             if s.is_info:
                 self.title += " (" + s.name + "=" + str(s.value) + ")"
 
-    def plot_map(self, driver):
+    def plot_map(self, backend):
 
         dimensions = dict((s.name, s.index) for s in self.slices)
 
-        driver.bounding_box(
+        backend.bounding_box(
             north=self.north, south=self.south, west=self.west, east=self.east
         )
 
-        driver.plot_netcdf(self.path, self.variable, dimensions)
+        backend.plot_netcdf(self.path, self.variable, dimensions)
 
     def __repr__(self):
         return "NetCDFField[%r,%r]" % (self.variable, self.slices)
@@ -252,10 +256,11 @@ class NetCDFReader(Reader):
             # self.log.info('Scanning file: %s var=%s coords=%s', self.path, name, v.coords)
 
             info = [value for value in v.coords if value not in v.dims]
-
+            non_dim_coords = {}
             for coord in v.coords:
 
                 if coord not in v.dims:
+                    non_dim_coords[coord] = ds[coord].values
                     continue
 
                 c = ds[coord]
@@ -268,14 +273,18 @@ class NetCDFReader(Reader):
 
                 use = False
 
-                if standard_name in ("longitude", "projection_x_coordinate") or (
-                    long_name == "longitude"
+                if (
+                    standard_name in ("longitude", "projection_x_coordinate")
+                    or (long_name == "longitude")
+                    or (axis == "X")
                 ):
                     has_lon = True
                     use = True
 
-                if standard_name in ("latitude", "projection_y_coordinate") or (
-                    long_name == "latitude"
+                if (
+                    standard_name in ("latitude", "projection_y_coordinate")
+                    or (long_name == "latitude")
+                    or (axis == "Y")
                 ):
                     has_lat = True
                     use = True
@@ -310,7 +319,7 @@ class NetCDFReader(Reader):
                 for value, coordinate in zip(values, coordinates):
                     slices.append(coordinate.make_slice(value))
 
-                fields.append(NetCDFField(self.path, ds, name, slices))
+                fields.append(NetCDFField(self.path, ds, name, slices, non_dim_coords))
 
         if not fields:
             raise Exception("NetCDFReader no 2D fields found in %s" % (self.path,))
@@ -332,10 +341,31 @@ class NetCDFReader(Reader):
             **options,
         )
 
+    def to_metview(self):
+        from climetlab.metview import mv_read
+
+        return mv_read(self.path)
+
     def plot_map(self, *args, **kwargs):
         return self.get_fields()[0].plot_map(*args, **kwargs)
 
+    # Used by normalisers
+    def to_datetime(self):
+        times = self.to_datetime_list()
+        assert len(times) == 1
+        return times[0]
 
-def reader(source, path, magic, deeper_check):
-    if magic[:4] in (b"\x89HDF", b"CDF\x01", b"CDF\x02"):
+    def to_datetime_list(self):
+        # TODO: check if that can be done faster
+        result = set()
+        for s in self.get_fields():
+            result.add(to_datetime(s.time))
+        return sorted(result)
+
+    def to_bounding_box(self):
+        return BoundingBox.multi_merge([s.to_bounding_box() for s in self.get_fields()])
+
+
+def reader(source, path, magic=None, deeper_check=False):
+    if magic is None or magic[:4] in (b"\x89HDF", b"CDF\x01", b"CDF\x02"):
         return NetCDFReader(source, path)
