@@ -8,6 +8,7 @@
 #
 
 import os
+import re
 import weakref
 from importlib import import_module
 
@@ -51,7 +52,7 @@ class Source(Base):
         if self.dataset:
             owner = self.dataset.name
         if owner is None:
-            owner = self.__class__.__name__.lower()
+            owner = re.sub(r"(?!^)([A-Z]+)", r"-\1", self.__class__.__name__).lower()
         return cache_file(owner, *args, **kwargs)
 
     @property
@@ -126,22 +127,32 @@ class SourceMaker:
         return self(name.replace("_", "-"))
 
 
-source = SourceMaker()
+get_source = SourceMaker()
 
 
 def register_source(module):
     register("source", module)
 
 
-def load_source(name: str, *args, context=None, **kwargs) -> Source:
+def load_source(name: str, *args, lazily=False, **kwargs) -> Source:
+
+    if lazily:
+        return load_source_lazily(name, *args, **kwargs)
+
     prev = None
-    src = source(name, *args, **kwargs)
+    src = get_source(name, *args, **kwargs)
     while src is not prev:
         prev = src
         src = src.mutate()
     return src
 
 
+def load_source_lazily(name, *args, **kwargs):
+    from climetlab.utils.lazy import LazySource
+
+    return LazySource(name, *args, **kwargs)
+
+
 def list_entries():
     here = os.path.realpath(os.path.dirname(__file__))
     result = []
